@@ -26,7 +26,7 @@ from ..base.constants import CONDA_HOMEPAGE_URL, CONDA_PACKAGE_EXTENSION_V1, REP
 from ..base.context import context
 from ..common.compat import (ensure_binary, ensure_text_type, ensure_unicode, iteritems, iterkeys,
                              string_types, text_type, with_metaclass)
-from ..common.io import ThreadLimitedThreadPoolExecutor, as_completed
+from ..common.io import ThreadLimitedThreadPoolExecutor
 from ..common.url import join_url, maybe_unquote
 from ..core.package_cache_data import PackageCacheData
 from ..exceptions import (CondaDependencyError, CondaHTTPError, CondaUpgradeError,
@@ -83,11 +83,13 @@ class SubdirData(object):
             subdirs = context.subdirs
         channel_urls = all_channel_urls(channels, subdirs=subdirs)
         check_whitelist(channel_urls)
+        subdir_query = lambda url: tuple(SubdirData(Channel(url), repodata_fn=repodata_fn).query(
+            package_ref_or_match_spec))
+
+        # TODO test timing with ProcessPoolExecutor
         with ThreadLimitedThreadPoolExecutor() as executor:
-            futures = tuple(executor.submit(
-                SubdirData(Channel(url), repodata_fn=repodata_fn).query, package_ref_or_match_spec
-            ) for url in channel_urls)
-            return tuple(concat(future.result() for future in as_completed(futures)))
+            result = tuple(concat(executor.map(subdir_query, channel_urls)))
+        return result
 
     def query(self, package_ref_or_match_spec):
         if not self._loaded:
@@ -624,7 +626,11 @@ def cache_fn_url(url, repodata_fn=REPODATA_FN):
     # url must be right-padded with '/' to not invalidate any existing caches
     if not url.endswith('/'):
         url += '/'
-    url += repodata_fn
+    # add the repodata_fn in for uniqueness, but keep it off for standard stuff.
+    #    It would be more sane to add it for everything, but old programs (Navigator)
+    #    are looking for the cache under keys without this.
+    if repodata_fn != REPODATA_FN:
+        url += repodata_fn
     md5 = hashlib.md5(ensure_binary(url)).hexdigest()
     return '%s.json' % (md5[:8],)
 
