@@ -656,8 +656,9 @@ to be incompatible with the existing python installation in your environment:\n{
 
 If python is on the left-most side of the chain, that's the version you've asked for.
 When python appears to the right, that indicates that the thing on the left is somehow
-not available for the python version you've asked for.
-Your current python version is ({ref}).
+not available for the python version you are constrained to.  Your current python version
+is ({ref}).  Note that conda will not change your python version to a different minor version
+unless you explicitly specify that.
 
         '''),
                     'request_conflict_with_history': dals('''
@@ -668,26 +669,44 @@ explicit spec that is not an explicit spec in this operation ({ref}):\n{specs}
                     '''),
                     'direct': dals('''
 
-The following specifications were found to be incompatible with each other:\n{specs}
+The following specifications were found to be incompatible with each other:\n
 
+                    '''),
+                    'cuda': dals('''
+
+The following specifications were found to be incompatible with your CUDA driver:\n{specs}
+
+Your installed CUDA driver is: {ref}
 ''')}
 
         msg = ""
         for class_name, dep_class in bad_deps.items():
             if dep_class:
                 _chains = []
-                for dep_chain, installed_blocker in dep_class:
-                    # Remove any target values from the MatchSpecs, convert to strings
-                    installed_blocker = str(MatchSpec(installed_blocker, target=None))
-                    dep_chain = [str(MatchSpec(dep, target=None)) for dep in dep_chain]
-                    _chains.append(dep_chain)
-
-                if _chains:
-                    _chains = self._format_chain_str(_chains)
+                if class_name == "direct":
+                    msg += messages["direct"]
+                    last_dep_entry = set(d[0][-1].name for d in dep_class)
+                    dep_constraint_map = {}
+                    for dep in dep_class:
+                        if dep[0][-1].name in last_dep_entry:
+                            if not dep_constraint_map.get(dep[0][-1].name):
+                                dep_constraint_map[dep[0][-1].name] = []
+                            dep_constraint_map[dep[0][-1].name].append(dep[0])
+                    for dep, chain in dep_constraint_map.items():
+                        msg += "\nPackage %s conflicts for:\n" % dep
+                        msg += "\n".join([" -> ".join([str(i) for i in c]) for c in chain])
                 else:
-                    _chains = [', '.join(c) for c in _chains]
-                msg += messages[class_name].format(specs=dashlist(_chains),
-                                                   ref=installed_blocker)
+                    for dep_chain, installed_blocker in dep_class:
+                        # Remove any target values from the MatchSpecs, convert to strings
+                        dep_chain = [str(MatchSpec(dep, target=None)) for dep in dep_chain]
+                        _chains.append(dep_chain)
+
+                    if _chains:
+                        _chains = self._format_chain_str(_chains)
+                    else:
+                        _chains = [', '.join(c) for c in _chains]
+                    msg += messages[class_name].format(specs=dashlist(_chains),
+                                                       ref=installed_blocker)
         if strict:
             msg += ('\nNote that strict channel priority may have removed '
                     'packages required for satisfiability.')
