@@ -14,8 +14,14 @@ def test_conda_subprocess():
     from subprocess import Popen, PIPE
     import conda
 
-    p = Popen(['echo', '"%s"' % conda.__version__], env=os.environ, stdout=PIPE, stderr=PIPE, 
-              shell=on_win)
+    try:
+        p = Popen(['echo', '"%s"' % conda.__version__], env=os.environ, stdout=PIPE, stderr=PIPE,
+                  shell=on_win)
+    except TypeError:
+        for k, v in os.environ.items():
+            if type(k) != str or type(v) != str:
+                print("%s (%s): %s (%s)" % (k, type(k), v, type(v)))
+        raise
     stdout, stderr = p.communicate()
     rc = p.returncode
     if rc != 0:
